package com.ruoyi.bst.bonus.service.impl;

import java.math.BigDecimal;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.bonus.domain.BonusQuery;
import com.ruoyi.bst.bonus.domain.enums.BonusStatus;
import com.ruoyi.bst.bonus.domain.vo.BonusStatVO;
import com.ruoyi.bst.bonus.mapper.BonusMapper;
import com.ruoyi.bst.bonus.service.BonusDashboard;
import com.ruoyi.common.utils.MathUtils;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.dashboard.constants.StatKeys;

@Service
public class BonusDashboardImpl implements BonusDashboard {

    @Autowired
    private BonusMapper bonusMapper;

    @Override
    public BonusStatVO selectStat(BonusQuery query, List<String> keys) {
        BonusStatVO vo = new BonusStatVO();
        if (keys.contains(StatKeys.BONUS_COUNT)) {
            vo.setCount(this.selectValidBonusCount(query));
        }
        if (keys.contains(StatKeys.BONUS_AMOUNT)) {
            vo.setAmount(this.selectValidBonusAmount(query));
        }
        if (keys.contains(StatKeys.BONUS_REFUND_AMOUNT)) {
            vo.setRefundAmount(this.selectValidBonusRefundAmount(query));
        }
        return vo;
    }

    // 查询有效分成数量
    private int selectValidBonusCount(BonusQuery query) {
        BonusQuery bonusQuery = new BonusQuery();
        BeanUtils.copyBeanProp(bonusQuery, query);
        bonusQuery.setStatusList(BonusStatus.valid());
        return MathUtils.dv(bonusMapper.selectCount(bonusQuery));
    }

    // 查询有效分成金额
    private BigDecimal selectValidBonusAmount(BonusQuery query) {
        BonusQuery bonusQuery = new BonusQuery();
        BeanUtils.copyBeanProp(bonusQuery, query);
        bonusQuery.setStatusList(BonusStatus.valid());
        return MathUtils.dv(bonusMapper.selectSumOfAmount(bonusQuery));
    }

    // 查询有效分成退款金额
    private BigDecimal selectValidBonusRefundAmount(BonusQuery query) {
        BonusQuery bonusQuery = new BonusQuery();
        BeanUtils.copyBeanProp(bonusQuery, query);
        bonusQuery.setStatusList(BonusStatus.valid());
        return MathUtils.dv(bonusMapper.selectSumOfRefundAmount(bonusQuery));
    }
    
}
