package com.ruoyi.bst.order.service.impl;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.domain.enums.OrderStatus;
import com.ruoyi.bst.order.domain.vo.OrderStatVO;
import com.ruoyi.bst.order.mapper.OrderMapper;
import com.ruoyi.bst.order.service.OrderDashboard;
import com.ruoyi.common.utils.MathUtils;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.dashboard.constants.StatKeys;

@Service
public class OrderDashboardImpl implements OrderDashboard {

    @Autowired
    private OrderMapper orderMapper;

    @Override
    public OrderStatVO selectStat(OrderQuery query, List<String> keys) {
        OrderStatVO vo = new OrderStatVO();
        // 订单用户数量
        if (keys.contains(StatKeys.ORDER_USER_COUNT)) {
            vo.setUserCount(this.selectValidOrderUserCount(query));
        }
        // 订单数量
        if (keys.contains(StatKeys.ORDER_COUNT)) {
            vo.setCount(this.selectValidOrderCount(query));
        }
        // 订单支付金额
        if (keys.contains(StatKeys.ORDER_PAY_AMOUNT)) {
            vo.setPayAmount(this.selectValidOrderPayAmount(query));
        }
        // 订单已退款金额
        if (keys.contains(StatKeys.ORDER_REFUNDED_AMOUNT)) {
            vo.setRefundedAmount(this.selectValidOrderRefundedAmount(query));
        }
        // 订单退款中金额
        if (keys.contains(StatKeys.ORDER_REFUNDING_AMOUNT)) {
            vo.setRefundingAmount(this.selectValidOrderRefundingAmount(query));
        }
        // 订单今日支付金额
        if (keys.contains(StatKeys.ORDER_TODAY_PAY_AMOUNT)) {
            vo.setTodayPayAmount(this.selectValidOrderTodayPayAmount(query));
        }
        // 订单今日退款金额
        if (keys.contains(StatKeys.ORDER_TODAY_REFUND_AMOUNT)) {
            vo.setTodayRefundedAmount(this.selectValidOrderTodayRefundedAmount(query));
        }
        // 订单今日退款中金额
        if (keys.contains(StatKeys.ORDER_TODAY_REFUNDING_AMOUNT)) {
            vo.setTodayRefundingAmount(this.selectValidOrderTodayRefundingAmount(query));
        }
        return vo;
    }

    // 查询有效订单的用户数量
    private int selectValidOrderUserCount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setStatusList(OrderStatus.valid());
        return MathUtils.dv(orderMapper.selectCount(orderQuery));
    }

    // 查询有效订单的数量
    private int selectValidOrderCount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setStatusList(OrderStatus.valid());
        return MathUtils.dv(orderMapper.selectCount(orderQuery));
    }

    // 查询有效订单的支付金额
    private BigDecimal selectValidOrderPayAmount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setStatusList(OrderStatus.valid());
        return MathUtils.dv(orderMapper.selectSumOfPayAmount(orderQuery));
    }

    // 查询有效订单的已退款金额
    private BigDecimal selectValidOrderRefundedAmount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setStatusList(OrderStatus.valid());
        return MathUtils.dv(orderMapper.selectSumOfRefundedAmount(orderQuery));
    }

    // 查询有效订单的退款中金额
    private BigDecimal selectValidOrderRefundingAmount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setStatusList(OrderStatus.valid());
        return MathUtils.dv(orderMapper.selectSumOfRefundingAmount(orderQuery));
    }

    // 查询有效订单的今日支付金额
    private BigDecimal selectValidOrderTodayPayAmount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setCreateDate(LocalDate.now());
        return this.selectValidOrderPayAmount(orderQuery);
    }

    // 查询有效订单的今日退款金额
    private BigDecimal selectValidOrderTodayRefundedAmount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setCreateDate(LocalDate.now());
        return this.selectValidOrderRefundedAmount(orderQuery);
    }

    // 查询有效订单的今日退款中金额
    private BigDecimal selectValidOrderTodayRefundingAmount(OrderQuery query) {
        OrderQuery orderQuery = new OrderQuery();
        BeanUtils.copyBeanProp(orderQuery, query);
        orderQuery.setCreateDate(LocalDate.now());
        return this.selectValidOrderRefundingAmount(orderQuery);
    }

}
