package com.ruoyi.system.user.service.impl;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.common.utils.MathUtils;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.dashboard.constants.StatKeys;
import com.ruoyi.system.user.domain.UserQuery;
import com.ruoyi.system.user.domain.vo.UserStatVO;
import com.ruoyi.system.user.mapper.UserMapper;
import com.ruoyi.system.user.service.UserDashboard;

@Service
public class UserDashboardImpl implements UserDashboard {

    @Autowired
    private UserMapper userMapper;

    @Override
    public BigDecimal selectMaxOfPoint(UserQuery query) {
        return userMapper.selectMaxOfPoint(query);
    }

    @Override
    public UserStatVO selectStat(UserQuery query, List<String> keys) {
        UserStatVO vo = new UserStatVO();
        if (keys.contains(StatKeys.USER_COUNT)) {
            vo.setCount(MathUtils.dv(userMapper.selectCount(query)));
        }
        if (keys.contains(StatKeys.USER_TODAY_COUNT)) {
            vo.setTodayCount(this.selectTodayCount(query));
        }
        if (keys.contains(StatKeys.USER_BALANCE)) {
            vo.setBalance(MathUtils.dv(userMapper.selectSumOfBalance(query)));
        }
        return vo;
    }

    /**
     * 查询今日新增用户数量
     */
    private int selectTodayCount(UserQuery query) {
        UserQuery todayQuery = new UserQuery();
        BeanUtils.copyBeanProp(todayQuery, query);
        todayQuery.setCreateDate(LocalDate.now());
        return MathUtils.dv(userMapper.selectCount(todayQuery));
    }

}
